@@ -22,7 +22,8 @@ def adrc_ss():
                  m_lim: tuple = (None, None),
                  half_gain: tuple = (False, False)):
         return pyadrc.StateSpace(
-            order, delta, b0, t_settle, k_eso, eso_init, r_lim, m_lim, half_gain)
+            order, delta, b0, t_settle,
+            k_eso, eso_init, r_lim, m_lim, half_gain)
     return _adrc_ss
 
 
@@ -100,7 +101,7 @@ def test_magnitude_limit(adrc_ss):
 
     assert u1 == 5
 
-    adrc.magnitude_limits = (0, 10)
+    adrc.magnitude_limiter = (0, 10)
     u2 = adrc(0, u1, 30)
 
     assert u2 == 10
@@ -115,8 +116,24 @@ def test_rate_limit(adrc_ss):
 
     assert (u2 - u1) == 1
 
-    adrc.rate_limits = (0, 5)
+    adrc.rate_limiter = (0, 5)
 
     u3 = adrc(0, u2, 30)
 
     assert (u3 - u2) == 5
+
+
+def test_reset(adrc_ss):
+
+    adrc = adrc_ss(order=1, delta=1, b0=10, t_settle=1, k_eso=1)
+
+    adrc.reset([10, 20])
+    assert np.array_equiv(adrc.eso_states.reshape(-1), np.array([10., 20.]))
+    adrc.reset()
+    assert np.array_equiv(adrc.eso_states.reshape(-1), [0., 0.])
+
+    adrc = adrc_ss(order=2, delta=1, b0=10, t_settle=1, k_eso=1)
+    adrc.reset([10, 20, 30])
+    assert np.array_equiv(adrc.eso_states.reshape(-1), [10., 20., 30.])
+    adrc.reset()
+    assert np.array_equiv(adrc.eso_states.reshape(-1), [0., 0., 0.])
